@@ -1,5 +1,5 @@
 package Net::Kubernetes::Resource::Pod;
-$Net::Kubernetes::Resource::Pod::VERSION = '0.08';
+$Net::Kubernetes::Resource::Pod::VERSION = '0.09';
 use Moose;
 
 =head1 NAME
@@ -8,13 +8,13 @@ Net::Kubernetes::Resource::Pod
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =cut
 
 extends 'Net::Kubernetes::Resource';
 
-with 'Net::Kubernetes::Resource::State';
-with 'Net::Kubernetes::Resource::Spec';
+with 'Net::Kubernetes::Resource::Role::State';
+with 'Net::Kubernetes::Resource::Role::Spec';
 
 return 42;
